OC.L10N.register(
    "logreader",
    {
    "Logging" : "Journalisation",
    "Log Reader" : "Lecteur du fichier journal",
    "A log reader for Nextcloud" : "Un lecteur du fichier journal pour Nextcloud",
    "Log reader for Nextcloud" : "Lecteur du fichier journal pour Nextcloud",
    "Error parsing log" : "Erreur lors de l'analyse du fichier journal",
    "Caused by " : "Causé par",
    "Debug" : "Déboguage",
    "Info" : "Info",
    "Warning" : "Avertissement",
    "Error" : "Erreur",
    "Fatal" : "Fatal",
    "Copy" : "Copier",
    "Copy raw" : "Copie brute",
    "Copy formatted" : "Copie formatée",
    "No server logs" : "Aucun journal serveur",
    "One or more entries are hidden by the log level filter" : "Des entrées sont masquées par le filtre sur le niveau de journalisation",
    "Everything is working fine" : "Tout fonctionne à merveille",
    "Level" : "Niveau",
    "App" : "App",
    "Message" : "Message",
    "Time" : "Heure",
    "Load log file" : "Charger un fichier journal",
    "Invalid log file" : "Fichier journal invalide",
    "Log levels" : "Niveaux du registre",
    "Log content" : "Contenu du registre",
    "Live update" : "Mise à jour en direct",
    "Download logs" : "Télécharger les journaux",
    "Load log file …" : "Charger un fichier journal..."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
